.. _toolbox-explanation:

Explanation
===========

Articles and posts about topics relevant -- directly or indirectly -- to the rAI-toolbox.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   explanation/perturbations
